@@ -1,6 +1,6 @@
 import typing
 
-from PyQt5 import QtWidgets, QtGui, QtCore
+from qtpy import QtWidgets, QtGui, QtCore
 
 from .toolbutton import RibbonToolButton
 from .utils import data_file_path
@@ -47,8 +47,8 @@ class RibbonGalleryPopupListWidget(RibbonGalleryListWidget):
 class RibbonGallery(QtWidgets.QFrame):
     """A widget that displays a gallery of buttons."""
     _popupWindowSize = QtCore.QSize(500, 500)
-    _buttons: list[RibbonToolButton] = []
-    _popupButtons: list[RibbonToolButton] = []
+    _buttons: typing.List[RibbonToolButton] = []
+    _popupButtons: typing.List[RibbonToolButton] = []
     _popupHideOnClick = False
 
     @typing.overload
@@ -114,7 +114,7 @@ class RibbonGallery(QtWidgets.QFrame):
         self._downButton.clicked.connect(self._listWidget.scrollToNextRow)
 
         self._popupWidget = QtWidgets.QWidget()
-        self._popupWidget.setFont(QtWidgets.qApp.font())
+        self._popupWidget.setFont(QtWidgets.QApplication.instance().font())
         self._popupWidget.setWindowFlags(QtCore.Qt.Popup)
         self._popupLayout = QtWidgets.QVBoxLayout(self._popupWidget)
         self._popupLayout.setContentsMargins(0, 0, 0, 0)
